@@ -49,12 +49,12 @@
 #' y <- c(3.8, 2.7, 4.0, 2.4)      # with obstructive airway disease
 #' z <- c(2.8, 3.4, 3.7, 2.2, 2.0) # with asbestosis
 #'
-#' datf <- data.frame(
-#'   g = g <- c(rep("ns", length(x)), rep("oad",
+#' dat <- data.frame(
+#'   g = c(rep("ns", length(x)), rep("oad",
 #'       length(y)), rep("a", length(z))),
-#'   x = x <- c(x, y, z))
+#'   x = c(x, y, z))
 #'
-#' adKSampleTest(x ~ g, datf)
+#' adKSampleTest(x ~ g, data = dat)
 #'
 # @references
 # Scholz, F.W., Stephens, M.A. (1987) K-Sample Anderson-Darling Tests.
@@ -226,7 +226,7 @@ adKSampleTest.default <-
 ##        PVAL <- gt.TkN / replicates
 ##    }
 ##
-    METHOD <- paste("Anderson-Darling k-sample test")
+    METHOD <- paste("Anderson-Darling k-Sample Test")
 
     ans <- list(method = METHOD,
                 data.name = DNAME,
